@@ -52,6 +52,11 @@ private:
 	std::string header;
 	bool updated = false;
 	SDL_TextInput textInputScope;
+	sago::SagoTextField headerLabel;
+	sago::SagoTextField enterLabel;
+	sago::SagoTextField cancelLabel;
+	sago::SagoTextField textField;
+	sago::SagoTextField cursorLabel;
 };
 
 #endif /* DIALOGBOX_HPP */
