@@ -49,6 +49,21 @@ void ButtonGfx::setSurfaces() {
 	}
 }
 
+sago::SagoTextField* ButtonGfx::getLabel(const std::string& text) {
+	const auto& theLabel = labels.find(text);
+	if (theLabel != labels.end()) {
+		return labels[text].get();
+	}
+	std::shared_ptr<sago::SagoTextField> newField = std::make_shared<sago::SagoTextField>();
+	newField->SetHolder(&globalData.spriteHolder->GetDataHolder());
+	newField->SetFont("freeserif");
+	newField->SetFontSize(30);
+	newField->SetOutline(1, {64,64,64,255});
+	newField->SetText(text);
+	labels[text] = newField;
+	return labels[text].get();
+}
+
 Button::Button() {
 	label = "";
 	marked = false;
@@ -98,7 +113,9 @@ static void drawToScreen(const Button& b) {
 		globalData.spriteHolder->GetSprite(menu_unmarked).Draw(globalData.screen, SDL_GetTicks(), b.x, b.y);
 	}
 
-	standardButton.thefont->draw(globalData.screen, b.x+standardButton.xsize/2,b.y+standardButton.ysize/2-standardButton.thefont->getHeight("%s",  b.label.c_str())/2, NFont::CENTER, "%s", b.label.c_str());
+	standardButton.getLabel(b.label)->Draw(globalData.screen, b.x+standardButton.xsize/2,b.y+standardButton.ysize/2,
+	                                       sago::SagoTextField::Alignment::center, sago::SagoTextField::VerticalAlignment::center);
+	//standardButton.thefont->drawCenterAlsoHeight(globalData.screen, b.x+standardButton.xsize/2,b.y+standardButton.ysize/2, b.label);
 }
 
 
@@ -115,7 +132,7 @@ void Menu::drawSelf(SDL_Renderer* target) {
 		drawToScreen(*b);
 	}
 	drawToScreen(exit);
-	standardButton.thefont->draw(target, 50, 50, "%s", title.c_str());
+	standardButton.getLabel(title)->Draw(target, 50, 50);
 }
 
 
@@ -273,7 +290,7 @@ bool isEscapeEvent(const SDL_Event& event) {
 		}
 	}
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_Y ) {
+		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_Y || event.cbutton.button == SDL_CONTROLLER_BUTTON_BACK ) {
 			return true;
 		}
 	}
@@ -301,6 +318,24 @@ bool Menu::IsActive() {
 void Menu::Draw(SDL_Renderer* target) {
 	placeButtons();
 	drawSelf(target);
+#if DEBUG
+	static unsigned long int Frames;
+	static unsigned long int Ticks;
+	static char FPS[10];
+	static sago::SagoTextField fpsField;
+	sagoTextSetBlueFont(fpsField);
+	Frames++;
+	if (SDL_GetTicks() >= Ticks + 1000) {
+		if (Frames > 999) {
+			Frames=999;
+		}
+		snprintf(FPS, sizeof(FPS), "%lu fps", Frames);
+		Frames = 0;
+		Ticks = SDL_GetTicks();
+	}
+	fpsField.SetText(FPS);
+	fpsField.Draw(globalData.screen, 800, 4);
+#endif
 }
 void Menu::ProcessInput(const SDL_Event& event, bool& processed) {
 	if (isUpEvent(event)) {
@@ -371,7 +406,8 @@ void Menu::Update() {
 				if (buttons.at(i)->isPopOnRun()) {
 					running = false;
 				}
-				globalData.mousex = 0;
+				//Quit here to ensure that we do not continue checking buttons after we have done the action.
+				return;
 			}
 		}
 		if (isClicked(exit,  globalData.mousex, globalData.mousey)) {
