@@ -27,11 +27,12 @@ http://blockattack.net
 
 #include <string>
 #include "SDL.h"
+#include <map>
 #include <vector>
-#include "Libs/NFont.h"
 #include "sago/SagoSprite.hpp"
 #include "sago/GameStateInterface.hpp"
 #include <memory>
+#include "sago/SagoTextField.hpp"
 
 //The ButtonGfx object hold common media for all buttons, so we can reskin them by only changeing one pointer
 struct ButtonGfx
@@ -39,9 +40,10 @@ struct ButtonGfx
 	//The size of the buttons, so we don't have to ask w and h from the SDL Surfaces each time
 	int xsize = 0;
 	int ysize = 0;
-	//A TTFont used for writing the label on the buttons
-	NFont* thefont = nullptr;
+	sago::SagoTextField* getLabel(const std::string& text);
 	void setSurfaces();
+private:
+	std::map<std::string, std::shared_ptr<sago::SagoTextField> > labels;
 };
 
 extern ButtonGfx standardButton;
