@@ -31,8 +31,28 @@ using std::string;
 using std::cerr;
 using std::vector;
 
-static void NFont_Write(SDL_Renderer* target, int x, int y, const char* text) {
-	globalData.nf_standard_blue_font.draw(target, x, y, "%s", text);
+static void setButtonFont(const sago::SagoDataHolder* holder, sago::SagoTextField& field, const char* text) {
+	field.SetHolder(holder);
+	field.SetFont("freeserif");
+	field.SetColor({255,255,255,255});
+	field.SetFontSize(24);
+	field.SetOutline(1, {128,128,128,255});
+	field.SetText(text);
+}
+
+sago::SagoTextField* ScoresDisplay::getCachedText(const std::string& text) {
+	std::shared_ptr<sago::SagoTextField> ptr = fieldCache[text];
+	if (!ptr) {
+		std::shared_ptr<sago::SagoTextField> newText = std::make_shared<sago::SagoTextField>();
+		sagoTextSetBlueFont(*newText.get());
+		newText->SetText(text);
+		fieldCache[text] = newText;
+	}
+	return fieldCache[text].get();
+}
+
+void ScoresDisplay::Write(SDL_Renderer* target, int x, int y, const char* text) {
+	getCachedText(text)->Draw(target, x, y);
 }
 
 const int numberOfPages = 3;
@@ -48,10 +68,10 @@ void ScoresDisplay::DrawBackgroundAndCalcPlacements() {
 void ScoresDisplay::DrawHighscores(int x, int y, bool endless) {
 	DrawBackgroundAndCalcPlacements();
 	if (endless) {
-		globalData.nf_standard_blue_font.draw(globalData.screen, x+100,y+100, "%s",_("Endless:") );
+		Write(globalData.screen, x+100,y+100, _("Endless:") );
 	}
 	else {
-		globalData.nf_standard_blue_font.draw(globalData.screen, x+100,y+100, "%s",_("Time Trial:") );
+		Write(globalData.screen, x+100,y+100, _("Time Trial:") );
 	}
 	for (int i =0; i<10; i++) {
 		record r;
@@ -65,8 +85,8 @@ void ScoresDisplay::DrawHighscores(int x, int y, bool endless) {
 		char playerName[32];
 		snprintf(playerScore, sizeof(playerScore), "%i", r.score);
 		snprintf(playerName, sizeof(playerName), "%s", r.name.c_str());
-		globalData.nf_standard_blue_font.draw(globalData.screen, x+420,y+150+i*35, "%s",playerScore);
-		globalData.nf_standard_blue_font.draw(globalData.screen, x+60,y+150+i*35, "%s",playerName);
+		Write(globalData.screen, x+420,y+150+i*35, playerScore);
+		Write(globalData.screen, x+60,y+150+i*35, playerName);
 	}
 }
 
@@ -74,60 +94,60 @@ void ScoresDisplay::DrawStats() {
 	DrawBackgroundAndCalcPlacements();
 	int y = 5;
 	const int y_spacing = 30;
-	NFont_Write(globalData.screen, 10,y,_("Stats") );
+	Write(globalData.screen, 10,y,_("Stats") );
 	y+=y_spacing*2;
-	NFont_Write(globalData.screen, 10,y,_("Chains") );
+	Write(globalData.screen, 10,y,_("Chains") );
 	for (int i=2; i<13; i++) {
 		y+=y_spacing;
-		NFont_Write(globalData.screen, 10,y,(std::to_string(i)+"X").c_str());
+		Write(globalData.screen, 10,y,(std::to_string(i)+"X").c_str());
 		string numberAsString = std::to_string(Stats::getInstance()->getNumberOf("chainX"+std::to_string(i)));
-		NFont_Write(globalData.screen, 300,y,numberAsString.c_str());
+		Write(globalData.screen, 300,y,numberAsString.c_str());
 	}
 	y+=y_spacing*2;
-	NFont_Write(globalData.screen, 10,y,_("Lines Pushed: ") );
+	Write(globalData.screen, 10,y,_("Lines Pushed: ") );
 	string numberAsString = std::to_string(Stats::getInstance()->getNumberOf("linesPushed"));
-	NFont_Write(globalData.screen, 300,y,numberAsString.c_str());
+	Write(globalData.screen, 300,y,numberAsString.c_str());
 
 	y+=y_spacing;
-	NFont_Write(globalData.screen, 10,y, _("Puzzles solved: ") );
+	Write(globalData.screen, 10,y, _("Puzzles solved: ") );
 	numberAsString = std::to_string(Stats::getInstance()->getNumberOf("puzzlesSolved"));
-	NFont_Write(globalData.screen, 300,y,numberAsString.c_str());
+	Write(globalData.screen, 300,y,numberAsString.c_str());
 
 	y+=y_spacing*2;
-	NFont_Write(globalData.screen, 10,y, _("Run time: ") );
+	Write(globalData.screen, 10,y, _("Run time: ") );
 	commonTime ct = TimeHandler::peekTime("totalTime",TimeHandler::ms2ct(SDL_GetTicks()));
 	y+=y_spacing;
-	NFont_Write(globalData.screen, 10, y, SPrintCF( _("Days: %i"), ct.days) );
+	Write(globalData.screen, 10, y, SPrintCF( _("Days: %i"), ct.days) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, 10, y, SPrintCF( _("Hours: %i"), ct.hours) );
+	Write(globalData.screen, 10, y, SPrintCF( _("Hours: %i"), ct.hours) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, 10, y, SPrintCF( _("Minutes: %i"), ct.minutes) );
+	Write(globalData.screen, 10, y, SPrintCF( _("Minutes: %i"), ct.minutes) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, 10, y, SPrintCF( _("Seconds: %i"), ct.seconds) );
+	Write(globalData.screen, 10, y, SPrintCF( _("Seconds: %i"), ct.seconds) );
 
 	y-=y_spacing*4; //Four rows back
 	const int x_offset3 = globalData.xsize/3+10; //Ofset for three rows
-	NFont_Write(globalData.screen, x_offset3,y, _("Play time: ") );
+	Write(globalData.screen, x_offset3,y, _("Play time: ") );
 	ct = TimeHandler::getTime("playTime");
 	y+=y_spacing;
-	NFont_Write(globalData.screen, x_offset3, y, SPrintCF( _("Days: %i"), ct.days) );
+	Write(globalData.screen, x_offset3, y, SPrintCF( _("Days: %i"), ct.days) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, x_offset3, y, SPrintCF( _("Hours: %i"), ct.hours) );
+	Write(globalData.screen, x_offset3, y, SPrintCF( _("Hours: %i"), ct.hours) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, x_offset3, y, SPrintCF( _("Minutes: %i"), ct.minutes) );
+	Write(globalData.screen, x_offset3, y, SPrintCF( _("Minutes: %i"), ct.minutes) );
 	y+=y_spacing;
-	NFont_Write(globalData.screen, x_offset3, y, SPrintCF( _("Seconds: %i"), ct.seconds) );
+	Write(globalData.screen, x_offset3, y, SPrintCF( _("Seconds: %i"), ct.seconds) );
 
 	const int x_offset = globalData.xsize/2+10;
 	y = 5+y_spacing*2;
-	NFont_Write(globalData.screen, x_offset,y, _("VS CPU (win/loss)") );
+	Write(globalData.screen, x_offset,y, _("VS CPU (win/loss)") );
 	for (int i=0; i<7; i++) {
 		y += y_spacing;
-		NFont_Write(globalData.screen, x_offset,y,string("AI "+std::to_string(i+1)).c_str());
+		Write(globalData.screen, x_offset,y,string("AI "+std::to_string(i+1)).c_str());
 		numberAsString = std::to_string(Stats::getInstance()->getNumberOf("defeatedAI"+std::to_string(i)));
 		string numberAsString2 = std::to_string(Stats::getInstance()->getNumberOf("defeatedByAI"+std::to_string(i)));
 		string toPrint = numberAsString + "/" + numberAsString2;
-		NFont_Write(globalData.screen, x_offset+230,y,toPrint.c_str());
+		Write(globalData.screen, x_offset+230,y,toPrint.c_str());
 	}
 }
 
@@ -156,16 +176,21 @@ void ScoresDisplay::Draw(SDL_Renderer*) {
 		DrawStats();
 	};
 
+	const sago::SagoDataHolder* holder = &globalData.spriteHolder->GetDataHolder();
 	//Draw buttons:
 	globalData.bHighScore.Draw(globalData.screen, 0, scoreX,scoreY);
 	globalData.bBack.Draw(globalData.screen, 0, backX, backY);
-	globalData.nf_button_font.draw(globalData.screen, backX+60,backY+10, NFont::CENTER ,_("Back"));
+	static sago::SagoTextField backLabel;
+	setButtonFont(holder, backLabel, _("Back"));
+	backLabel.Draw(globalData.screen, backX+60,backY+10, sago::SagoTextField::Alignment::center);
 	globalData.bNext.Draw(globalData.screen, 0, nextX, nextY);
-	globalData.nf_button_font.draw(globalData.screen, nextX+60,nextY+10, NFont::CENTER,_("Next"));
+	static sago::SagoTextField nextLabel;
+	setButtonFont(holder, nextLabel, _("Next"));
+	nextLabel.Draw(globalData.screen, nextX+60, nextY+10, sago::SagoTextField::Alignment::center);
 
 	//Draw page number
 	string pageXofY = SPrintStringF(_("Page %i of %i"), page+1, numberOfPages);
-	NFont_Write(globalData.screen, globalData.xsize/2-globalData.nf_standard_blue_font.getWidth( "%s", pageXofY.c_str())/2, globalData.ysize-60, pageXofY.c_str());
+	getCachedText(pageXofY)->Draw(globalData.screen,  globalData.xsize/2, globalData.ysize-60, sago::SagoTextField::Alignment::center);
 }
 
 void ScoresDisplay::ProcessInput(const SDL_Event& event, bool& processed) {
