@@ -37,6 +37,8 @@ struct ControllerStatus {
 };
 
 static std::map<SDL_JoystickID, ControllerStatus> controllerStatusMap;
+static std::map<std::string, int> gamecontrollers_assigned;
+static std::vector<std::string> supportedControllers;
 
 
 void GameControllerSetVerbose(bool value) {
@@ -61,7 +63,6 @@ static std::string GetGuidAsHex(const SDL_JoystickGUID& guid) {
 	return ret;
 }
 
-static std::map<std::string, int> gamecontrollers_assigned;
 
 static int GetNextPlayerByGui(const SDL_JoystickGUID& guid) {
 	Config::getInstance()->setDefault("gc_AllToOnePlayer", "0");
@@ -100,6 +101,7 @@ void InitGameControllers() {
 			SDL_JoystickGUID guid = SDL_JoystickGetGUID(j);
 			int assingToPlayer = GetNextPlayerByGui(guid);
 			controllerStatusMap[instanceId].player = assingToPlayer;
+			supportedControllers.push_back(GameControllerGetName(controller));
 			if (verbose) {
 				std::cout << "Supported game controller detected: " << GameControllerGetName(controller) << ", mapping: " << SDL_GameControllerMapping(controller) <<  "\n";
 				std::cout << "Assigned to player: " << controllerStatusMap[instanceId].player << "\n";
@@ -108,6 +110,10 @@ void InitGameControllers() {
 	}
 }
 
+const std::vector<std::string>& GetSupportedControllerNames() {
+	return supportedControllers;
+}
+
 void checkDeadZone(const SDL_Event& event) {
 	if (event.type != SDL_CONTROLLERAXISMOTION) {
 		return;  //assert?
@@ -252,5 +258,15 @@ bool isPlayerPushEvent(int playerNumber, const SDL_Event& event) {
 			return true;
 		}
 	}
+	if (event.type == SDL_CONTROLLERAXISMOTION  && (event.caxis.axis == SDL_CONTROLLER_AXIS_TRIGGERLEFT || event.caxis.axis == SDL_CONTROLLER_AXIS_TRIGGERRIGHT ) ) {
+		checkDeadZone(event);
+		const SDL_ControllerAxisEvent& a = event.caxis;
+		if (getDeadZone(a.which, a.axis)) {
+			if (event.caxis.value > deadZoneLimit) {
+				setDeadZone(a.which,a.axis,false);
+				return true;
+			}
+		}
+	}
 	return false;
 }
\ No newline at end of file
