@@ -24,13 +24,13 @@ http://www.blockattack.net
 #ifndef _GLOBAL_HPP
 #define	_GLOBAL_HPP
 
-#include "Libs/NFont.h"
 #include <memory>
 #include "sago/SagoSpriteHolder.hpp"
 #include "highscore.h"
 #include "sago/GameStateInterface.hpp"
 #include "TextManager.hpp"
 #include "ExplosionManager.hpp"
+#include "sago/SagoTextField.hpp"
 
 void MainMenu();
 void ResetFullscreen();
@@ -45,6 +45,9 @@ void UpdateMouseCoordinates(const SDL_Event& event, int& mousex, int& mousey);
 void DrawIMG(const sago::SagoSprite& sprite, SDL_Renderer* target, int x, int y);
 void DrawIMG_Bounded(const sago::SagoSprite& sprite, SDL_Renderer* target, int x, int y, int minx, int miny, int maxx, int maxy);
 
+void sagoTextSetHelpFont(sago::SagoTextField& field);
+void sagoTextSetBlueFont(sago::SagoTextField& field);
+
 struct GlobalData {
 	sago::SagoSprite bHighScore;
 	sago::SagoSprite bBack;
@@ -53,9 +56,6 @@ struct GlobalData {
 	sago::SagoSprite iLevelCheckBox;
 	sago::SagoSprite iLevelCheckBoxMarked;
 	sago::SagoSprite iCheckBoxArea;
-	NFont nf_scoreboard_font;
-	NFont nf_standard_blue_font;
-	NFont nf_button_font;
 	bool MusicEnabled;			//true if background music is enabled
 	bool SoundEnabled;			//true if sound effects is enabled
 	bool bFullscreen;			//true if game is running fullscreen
@@ -63,7 +63,7 @@ struct GlobalData {
 	std::string player1name;
 	std::string player2name;
 	SDL_Renderer *screen = nullptr;        //The whole screen;
-	Mix_Chunk *typingChunk;
+	sago::SoundHandler typingChunk;
 	sago::SagoSprite mouse;
 	bool highPriority = false;
 	bool NoSound = false;	
