@@ -34,6 +34,7 @@ http://www.blockattack.net
 #define WITH_SDL 1
 
 #include "sago/SagoSpriteHolder.hpp"
+#include "sago/SagoTextBox.hpp"
 #include <iostream>
 #include <stdlib.h>
 #include <time.h>           //Used for srand()
@@ -43,7 +44,6 @@ http://www.blockattack.net
 #include <SDL_mixer.h>      //Used for sound & music
 #include <SDL_image.h>      //To load PNG images!
 #include <physfs.h>         //Abstract file system. To use containers
-#include "Libs/NFont.h"
 #include <vector>
 #include "MenuSystem.h"
 #include "puzzlehandler.hpp"
@@ -111,6 +111,16 @@ static void PhysFsCreateFolders() {
 	PHYSFS_mkdir("puzzles");
 }
 
+static void setGameOverFont(const sago::SagoDataHolder* holder, sago::SagoTextBox& field, const char* text) {
+	field.SetHolder(holder);
+	field.SetFont("freeserif");
+	field.SetColor({0,0,255,255});
+	field.SetFontSize(60);
+	field.SetOutline(3, {192,192,255,255});
+	field.SetMaxWidth(280);
+	field.SetText(text);
+}
+
 //Load all image files to memory
 static int InitImages(sago::SagoSpriteHolder& holder) {
 	bricks[0] = holder.GetSprite("block_blue");
@@ -144,10 +154,9 @@ static int InitImages(sago::SagoSpriteHolder& holder) {
 	counter[0] = holder.GetSprite("counter_1");
 	counter[1] = holder.GetSprite("counter_2");
 	counter[2] = holder.GetSprite("counter_3");
-	iGameOver = holder.GetSprite("i_game_over");
-	iWinner = holder.GetSprite("i_winner");
-	iDraw = holder.GetSprite("i_draw");
-	iLoser = holder.GetSprite("i_loser");
+	setGameOverFont(&holder.GetDataHolder(),tbGameOver, _("GAME OVER"));
+	setGameOverFont(&holder.GetDataHolder(),tbWinner, _("WINNER"));
+	setGameOverFont(&holder.GetDataHolder(),tbDraw, _("DRAW"));
 	iChainFrame = holder.GetSprite("chain_frame");
 	globalData.iLevelCheck = holder.GetSprite("i_level_check");
 	globalData.iLevelCheckBox = holder.GetSprite("i_level_check_box");
@@ -181,52 +190,45 @@ static int InitImages(sago::SagoSpriteHolder& holder) {
 	globalData.mouse = holder.GetSprite("mouse");
 	backBoard = holder.GetSprite("back_board");
 
-	SDL_Color nf_button_color, nf_standard_blue_color, nf_standard_small_color;
-	memset(&nf_button_color,0,sizeof(SDL_Color));
-	nf_button_color.b = 255;
-	nf_button_color.g = 255;
-	nf_button_color.r = 255;
-	nf_button_color.a = 255;
-	nf_standard_blue_color.b = 255;
-	nf_standard_blue_color.g = 0;
-	nf_standard_blue_color.r = 0;
-	nf_standard_blue_color.a = 255;
-	nf_standard_small_color.b = 0;
-	nf_standard_small_color.g = 0;
-	nf_standard_small_color.r = 200;
-	nf_standard_small_color.a = 255;
-	globalData.nf_button_font.load(globalData.screen, holder.GetDataHolder().getFontPtr("freeserif", 24), nf_button_color);
-	globalData.nf_standard_blue_font.load(globalData.screen, holder.GetDataHolder().getFontPtr("freeserif", 30), nf_standard_blue_color);
-	nf_standard_small_font.load(globalData.screen, holder.GetDataHolder().getFontPtr("freeserif", 16), nf_standard_small_color);
-	globalData.nf_scoreboard_font.load(globalData.screen, holder.GetDataHolder().getFontPtr("penguinattack", 20), nf_button_color);
+	sagoTextSetBlueFont(player1name);
+	sagoTextSetBlueFont(player2name);
+	sagoTextSetBlueFont(player1time);
+	sagoTextSetBlueFont(player2time);
+	sagoTextSetBlueFont(player1score);
+	sagoTextSetBlueFont(player2score);
+	sagoTextSetBlueFont(player1chain);
+	sagoTextSetBlueFont(player2chain);
+	sagoTextSetBlueFont(player1speed);
+	sagoTextSetBlueFont(player2speed);
+
 
 //Loads the sound if sound present
 	if (!globalData.NoSound) {
 		//And here the music:
-		bgMusic = holder.GetDataHolder().getMusicPtr("bgmusic");
-		highbeatMusic = holder.GetDataHolder().getMusicPtr("highbeat");
+		bgMusic = holder.GetDataHolder().getMusicHandler("bgmusic");
+		highbeatMusic = holder.GetDataHolder().getMusicHandler("highbeat");
 		//the music... we just hope it exists, else the user won't hear anything
 		//Same goes for the sounds
-		boing = holder.GetDataHolder().getSoundPtr("pop");
-		applause = holder.GetDataHolder().getSoundPtr("applause");
-		photoClick = holder.GetDataHolder().getSoundPtr("cameraclick");
-		globalData.typingChunk = holder.GetDataHolder().getSoundPtr("typing");
-		counterChunk = holder.GetDataHolder().getSoundPtr("counter");
-		counterFinalChunk = holder.GetDataHolder().getSoundPtr("counter_final");
+		boing = holder.GetDataHolder().getSoundHandler("pop");
+		applause = holder.GetDataHolder().getSoundHandler("applause");
+		photoClick = holder.GetDataHolder().getSoundHandler("cameraclick");
+		globalData.typingChunk = holder.GetDataHolder().getSoundHandler("typing");
+		counterChunk = holder.GetDataHolder().getSoundHandler("counter");
+		counterFinalChunk = holder.GetDataHolder().getSoundHandler("counter_final");
 		const int soundVolume = 84;  //0-128
-		Mix_VolumeChunk(boing, soundVolume);
-		Mix_VolumeChunk(applause, soundVolume);
-		Mix_VolumeChunk(photoClick, soundVolume);
-		Mix_VolumeChunk(globalData.typingChunk, soundVolume);
-		Mix_VolumeChunk(counterChunk, soundVolume);
-		Mix_VolumeChunk(counterFinalChunk, soundVolume);
+		Mix_VolumeChunk(boing.get(), soundVolume);
+		Mix_VolumeChunk(applause.get(), soundVolume);
+		Mix_VolumeChunk(photoClick.get(), soundVolume);
+		Mix_VolumeChunk(globalData.typingChunk.get(), soundVolume);
+		Mix_VolumeChunk(counterChunk.get(), soundVolume);
+		Mix_VolumeChunk(counterFinalChunk.get(), soundVolume);
 	} //All sound has been loaded or not
 	return 0;
 } //InitImages()
 
 /*Draws a image from on a given Surface. Takes source image, destination surface and coordinates*/
 void DrawIMG(const sago::SagoSprite& sprite, SDL_Renderer* target, int x, int y) {
-	sprite.Draw(target, SDL_GetTicks() ,x,y);
+	sprite.Draw(target, SDL_GetTicks(),x,y);
 }
 
 void DrawIMG_Bounded(const sago::SagoSprite& sprite, SDL_Renderer* target, int x, int y, int minx, int miny, int maxx, int maxy) {
@@ -238,18 +240,9 @@ void DrawIMG_Bounded(const sago::SagoSprite& sprite, SDL_Renderer* target, int x
 	sprite.DrawBounded(target, SDL_GetTicks(),x,y,bounds);
 }
 
-
-static void NFont_Write(SDL_Renderer* target, int x, int y, const string& text) {
-	globalData.nf_standard_blue_font.draw(target, x, y, "%s", text.c_str());
-}
-
-static void NFont_Write(SDL_Renderer* target, int x, int y, const char* text) {
-	globalData.nf_standard_blue_font.draw(target, x, y, "%s", text);
-}
-
 SDL_Window* sdlWindow;
 
-std::unique_ptr<sago::SagoDataHolder> dataHolder;
+sago::SagoDataHolder dataHolder;
 
 void ResetFullscreen() {
 	Mix_HaltMusic();  //We need to reload all data in case the screen type changes. Music must be stopped before unload.
@@ -259,8 +252,8 @@ void ResetFullscreen() {
 	else {
 		SDL_SetWindowFullscreen(sdlWindow, 0);
 	}
-	dataHolder.reset(new sago::SagoDataHolder(globalData.screen));
-	globalData.spriteHolder.reset(new sago::SagoSpriteHolder( *(dataHolder.get()) ) );
+	dataHolder.invalidateAll(globalData.screen);
+	globalData.spriteHolder.reset(new sago::SagoSpriteHolder( dataHolder ) );
 	InitImages(*(globalData.spriteHolder.get()) );
 	SDL_ShowCursor(SDL_DISABLE);
 }
@@ -332,16 +325,13 @@ void writeScreenShot() {
 	SDL_FreeSurface(sreenshotSurface);
 	if (!globalData.NoSound) {
 		if (globalData.SoundEnabled) {
-			Mix_PlayChannel(1, photoClick, 0);
+			Mix_PlayChannel(1, photoClick.get(), 0);
 		}
 	}
 }
 
 //Function to return the name of a key, to be displayed...
-static string getKeyName(SDL_Keycode key) {
-	string keyname(SDL_GetKeyName(key));
-	return keyname;
-}
+string getKeyName(SDL_Keycode key);
 
 
 void RunGameState(sago::GameStateInterface& state ) {
@@ -394,6 +384,23 @@ void OpenScoresDisplay() {
 }
 
 
+static sago::SagoTextField* getSmallInt(size_t number) {
+	static std::vector<std::shared_ptr<sago::SagoTextField> > smallFontCache;
+	if (smallFontCache.size() < number+1) {
+		smallFontCache.resize(number+1);
+	}
+	if (!smallFontCache[number]) {
+		std::shared_ptr<sago::SagoTextField> newNumber = std::make_shared<sago::SagoTextField>();
+		newNumber->SetHolder(&globalData.spriteHolder->GetDataHolder());
+		newNumber->SetFont("freeserif");
+		newNumber->SetFontSize(16);
+		newNumber->SetColor({255,0,0,255});
+		newNumber->SetText(std::to_string(number));
+		smallFontCache[number] = newNumber;
+	}
+	return smallFontCache[number].get();
+}
+
 //Draws the balls and explosions
 static void DrawBalls() {
 	for (size_t i = 0; i< theBallManager.ballArray.size(); i++) {
@@ -412,11 +419,30 @@ static void DrawBalls() {
 			int y = globalData.theTextManager.textArray[i].getY()-12;
 			DrawIMG(iChainFrame,globalData.screen,x,y);
 
-			nf_standard_small_font.draw(globalData.screen, x+12,y+7, NFont::CENTER, "%s", globalData.theTextManager.textArray[i].getText());
+			getSmallInt(globalData.theTextManager.textArray[i].getText())->Draw(globalData.screen, x+12, y+7,
+			        sago::SagoTextField::Alignment::center);
 		}
 	}
 }    //DrawBalls
 
+template <class T> void sagoTextSetHelpFont(T& field) {
+	field.SetHolder(&globalData.spriteHolder->GetDataHolder());
+	field.SetFont("freeserif");
+	field.SetFontSize(30);
+	field.SetOutline(1, {128,128,128,255});
+}
+
+void sagoTextSetHelpFont(sago::SagoTextField& gametypeNameField) {
+	sagoTextSetHelpFont<sago::SagoTextField>(gametypeNameField);
+}
+
+void sagoTextSetBlueFont(sago::SagoTextField& field) {
+	field.SetHolder(&globalData.spriteHolder->GetDataHolder());
+	field.SetFont("freeserif");
+	field.SetFontSize(30);
+	field.SetColor({0,0,255,255});
+	field.SetOutline(1, {128,128,255,255});
+}
 
 //draws everything
 void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* theGame2) {
@@ -426,16 +452,18 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 	theGame2->DoPaintJob();
 	string strHolder;
 	strHolder = std::to_string(theGame->GetScore()+theGame->GetHandicap());
-	NFont_Write(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+100,strHolder.c_str());
+	player1score.SetText(strHolder);
+	player1score.Draw(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+100);
 	if (theGame->GetAIenabled()) {
-		NFont_Write(globalData.screen, theGame->GetTopX()+10,theGame->GetTopY()-34,_("AI") );
+		player1name.SetText(_("AI"));
 	}
-	else if (editorMode || singlePuzzle) {
-		NFont_Write(globalData.screen, theGame->GetTopX()+10,theGame->GetTopY()-34,_("Playing field") );
+	else if (singlePuzzle) {
+		player1name.SetText(_("Playing field"));
 	}
 	else {
-		NFont_Write(globalData.screen, theGame->GetTopX()+10,theGame->GetTopY()-34, globalData.player1name);
+		player1name.SetText(globalData.player1name);
 	}
+	player1name.Draw(globalData.screen, theGame->GetTopX()+10,theGame->GetTopY()-34);
 	if (theGame->isTimeTrial()) {
 		int tid = (int)SDL_GetTicks()-theGame->GetGameStartedAt();
 		int minutes;
@@ -460,8 +488,7 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 		else {
 			strHolder = std::to_string(minutes)+":0"+std::to_string(seconds);
 		}
-		//if ((SoundEnabled)&&(!NoSound)&&(tid>0)&&(seconds<5)&&(minutes == 0)&&(seconds>1)&&(!(Mix_Playing(6)))) Mix_PlayChannel(6,heartBeat,0);
-		NFont_Write(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+150,strHolder.c_str());
+		player1time.SetText(strHolder);
 	}
 	else {
 		int minutes = ((abs((int)SDL_GetTicks()-(int)theGame->GetGameStartedAt())))/60/1000;
@@ -478,20 +505,23 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 		else {
 			strHolder = std::to_string(minutes)+":0"+std::to_string(seconds);
 		}
-		NFont_Write(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+150,strHolder.c_str());
+		player1time.SetText(strHolder);
 	}
+	player1time.Draw(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+150);
 	strHolder = std::to_string(theGame->GetChains());
-	NFont_Write(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+200,strHolder.c_str());
+	player1chain.SetText(strHolder);
+	player1chain.Draw(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+200);
 	//drawspeedLevel:
 	strHolder = std::to_string(theGame->GetSpeedLevel());
-	NFont_Write(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+250,strHolder.c_str());
+	player1speed.SetText(strHolder);
+	player1speed.Draw(globalData.screen, theGame->GetTopX()+310,theGame->GetTopY()+250);
 	if ((theGame->isStageClear()) &&(theGame->GetTopY()+700+50*(theGame->GetStageClearLimit()-theGame->GetLinesCleared())-theGame->GetPixels()-1<600+theGame->GetTopY())) {
 		oldBubleX = theGame->GetTopX()+280;
 		oldBubleY = theGame->GetTopY()+650+50*(theGame->GetStageClearLimit()-theGame->GetLinesCleared())-theGame->GetPixels()-1;
 		DrawIMG(stageBobble,globalData.screen,theGame->GetTopX()+280,theGame->GetTopY()+650+50*(theGame->GetStageClearLimit()-theGame->GetLinesCleared())-theGame->GetPixels()-1);
 	}
 	//player1 finnish, player2 start
-	if (!editorMode /*&& !singlePuzzle*/ ) {
+	if (true ) {
 		/*
 		 *If single player mode (and not VS)
 		 */
@@ -519,33 +549,49 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 				infostring = _("Score as much as possible. No time limit.");
 			}
 			if (infostring.length() > 0) {
-				NFont_Write(globalData.screen, theGame2->GetTopX()+7,theGame2->GetTopY()+10, gametypeName);
-				NFont_Write(globalData.screen, theGame2->GetTopX()+7,theGame2->GetTopY()+160, _("Objective:"));
-				globalData.nf_standard_blue_font.drawBox(globalData.screen, { static_cast<float>(theGame2->GetTopX()+7),static_cast<float>(theGame2->GetTopY()+160+32), 280, 200}, "%s", infostring.c_str());
+				static sago::SagoTextBox infoBox;
+				static sago::SagoTextField objectiveField;
+				static sago::SagoTextField gametypeNameField;
+				sagoTextSetHelpFont(infoBox);
+				infoBox.SetMaxWidth(290);
+				infoBox.SetText(infostring);
+				sagoTextSetHelpFont(objectiveField);
+				objectiveField.SetText(_("Objective:"));
+				sagoTextSetHelpFont(gametypeNameField);
+				gametypeNameField.SetText(gametypeName);
+				gametypeNameField.Draw(globalData.screen, theGame2->GetTopX()+7,theGame2->GetTopY()+10);
+				objectiveField.Draw(globalData.screen, theGame2->GetTopX()+7, theGame2->GetTopY()+160);
+				infoBox.Draw(globalData.screen, theGame2->GetTopX()+7, theGame2->GetTopY()+160+32);
 			}
 
 			//Write the keys that are in use
 			int y = theGame2->GetTopY()+400;
-			NFont_Write(globalData.screen, theGame2->GetTopX()+7,y,_("Movement keys:") );
-			NFont_Write(globalData.screen, theGame2->GetTopX()+7,y+40,(getKeyName(keySettings[0].left)+", "+getKeyName(keySettings[0].right)+"," ).c_str() );
-			NFont_Write(globalData.screen, theGame2->GetTopX()+7,y+76,(getKeyName(keySettings[0].up)+", "+getKeyName(keySettings[0].down)).c_str() );
-			NFont_Write(globalData.screen, theGame2->GetTopX()+7,y+120,( _("Switch: ")+getKeyName(keySettings[0].change) ).c_str() );
+			std::string controldBoxText = std::string(_("Movement keys:"))+"\n"+getKeyName(keySettings[0].left)+", "+getKeyName(keySettings[0].right)+",\n"
+			                              + getKeyName(keySettings[0].up)+", "+getKeyName(keySettings[0].down)+"\n"
+			                              + _("Switch: ") + getKeyName(keySettings[0].change);
 			if (theGame->isPuzzleMode()) {
-				NFont_Write(globalData.screen, theGame2->GetTopX()+7,y+160,( _("Restart: ")+getKeyName(keySettings[0].push) ).c_str() );
+				controldBoxText += std::string("\n") + _("Restart: ")+getKeyName(keySettings[0].push);
 			}
 			else {
-				NFont_Write(globalData.screen, theGame2->GetTopX()+7,y+160,( _("Push line: ")+getKeyName(keySettings[0].push) ).c_str() );
+				controldBoxText += std::string("\n") + _("Push line: ")+getKeyName(keySettings[0].push);
 			}
-
+			static sago::SagoTextBox controldBox;
+			controldBox.SetHolder(&globalData.spriteHolder->GetDataHolder());
+			sagoTextSetHelpFont(controldBox);
+			controldBox.SetMaxWidth(290);
+			controldBox.SetText(controldBoxText);
+			controldBox.Draw(globalData.screen, theGame2->GetTopX()+7,y);
 		}
 		strHolder = std::to_string(theGame2->GetScore()+theGame2->GetHandicap());
-		NFont_Write(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+100,strHolder.c_str());
+		player2score.SetText(strHolder);
+		player2score.Draw(globalData.screen, theGame2->GetTopX()+310, theGame2->GetTopY()+100);
 		if (theGame2->GetAIenabled()) {
-			NFont_Write(globalData.screen, theGame2->GetTopX()+10,theGame2->GetTopY()-34,_("AI") );
+			player2name.SetText(_("AI"));
 		}
 		else {
-			NFont_Write(globalData.screen, theGame2->GetTopX()+10,theGame2->GetTopY()-34,theGame2->name);
+			player2name.SetText(theGame2->name);
 		}
+		player2name.Draw(globalData.screen, theGame2->GetTopX()+10,theGame2->GetTopY()-34);
 		if (theGame2->isTimeTrial()) {
 			int tid = (int)SDL_GetTicks()-theGame2->GetGameStartedAt();
 			int minutes;
@@ -570,8 +616,6 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 			else {
 				strHolder = std::to_string(minutes)+":0"+std::to_string(seconds);
 			}
-			//if ((SoundEnabled)&&(!NoSound)&&(tid>0)&&(seconds<5)&&(minutes == 0)&&(seconds>1)&&(!(Mix_Playing(6)))) Mix_PlayChannel(6,heartBeat,0);
-			NFont_Write(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+150,strHolder.c_str());
 		}
 		else {
 			int minutes = (abs((int)SDL_GetTicks()-(int)theGame2->GetGameStartedAt()))/60/1000;
@@ -588,12 +632,15 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 			else {
 				strHolder = std::to_string(minutes)+":0"+std::to_string(seconds);
 			}
-			NFont_Write(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+150,strHolder.c_str());
 		}
+		player2time.SetText(strHolder);
+		player2time.Draw(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+150);
 		strHolder = std::to_string(theGame2->GetChains());
-		NFont_Write(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+200,strHolder.c_str());
+		player2chain.SetText(strHolder);
+		player2chain.Draw(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+200);
 		strHolder = std::to_string(theGame2->GetSpeedLevel());
-		NFont_Write(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+250,strHolder.c_str());
+		player2speed.SetText(strHolder);
+		player2speed.Draw(globalData.screen, theGame2->GetTopX()+310,theGame2->GetTopY()+250);
 	}
 	//player2 finnish
 
@@ -603,6 +650,8 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 	DrawBalls();
 
 #if DEBUG
+	static sago::SagoTextField fpsField;
+	sagoTextSetBlueFont(fpsField);
 	Frames++;
 	if (SDL_GetTicks() >= Ticks + 1000) {
 		if (Frames > 999) {
@@ -612,8 +661,8 @@ void DrawEverything(int xsize, int ysize,BlockGameSdl* theGame, BlockGameSdl* th
 		Frames = 0;
 		Ticks = SDL_GetTicks();
 	}
-
-	globalData.nf_standard_blue_font.draw(globalData.screen, 800, 4, "%s", FPS);
+	fpsField.SetText(FPS);
+	fpsField.Draw(globalData.screen, 800, 4);
 #endif
 }
 
@@ -746,6 +795,7 @@ struct globalConfig {
 	string puzzleName;
 	bool allowResize = true;
 	bool autoScale = true;
+	bool softwareRenderer = false;
 };
 
 static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
@@ -766,6 +816,7 @@ static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
 	("config,c", boost::program_options::value<vector<string> >(), "Read a config file with the values. Can be given multiple times")
 	("nosound", "Disables the sound. Can be used if sound errors prevents you from starting")
 	("priority", "Causes the game to not sleep between frames.")
+	("software-renderer", "Asks SDL2 to use software renderer")
 	("verbose-basic", "Enables basic verbose messages")
 	("verbose-game-controller", "Enables verbose messages regarding controllers")
 	("print-search-path", "Prints the search path and quits")
@@ -817,6 +868,8 @@ static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
 		cout << "Examples:" << "\n";
 		cout << "\tblockattack          \tStart the game normally" << "\n";
 		cout << "\tblockattack --nosound\tStart the game without sound. Can be used if sound problems prevents the game from starting" << "\n";
+		cout << "\tblockattack --puzzle-level-file puzzle.levels --puzzle-single-level 3\tStart the game with the default puzzles in level 3" << "\n";
+		cout << "\tblockattack --bind-text-domain /dev/null\t Disables translations" << "\n";
 		cout << "\n";
 		cout << "Report bugs to the issue tracker here: <https://github.com/blockattack/blockattack-game/issues>" << "\n";
 		exit(0);
@@ -836,6 +889,9 @@ static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
 	if (vm.count("priority")) {
 		globalData.highPriority = true;
 	}
+	if (vm.count("software-renderer")) {
+		conf.softwareRenderer = true;
+	}
 	if (vm.count("verbose-basic")) {
 		globalData.verboseLevel++;
 	}
@@ -948,6 +1004,7 @@ int main(int argc, char* argv[]) {
 		Config* configSettings = Config::getInstance();
 		//configSettings->setString("aNumber"," A string");
 		//configSettings->save();
+		int screenHeight = 768;
 		if (configSettings->exists("fullscreen")) { //Test if an configFile exists
 			globalData.bFullscreen = (bool)configSettings->getInt("fullscreen");
 			globalData.MusicEnabled = (bool)configSettings->getInt("musicenabled");
@@ -1002,6 +1059,9 @@ int main(int argc, char* argv[]) {
 			if (configSettings->exists("ysize")) {
 				globalData.ysize = configSettings->getInt("ysize");
 			}
+			if (configSettings->exists("screenHeight")) {
+				screenHeight = configSettings->getInt("screenHeight");
+			}
 			if (globalData.verboseLevel) {
 				cout << "Data loaded from config file" << "\n";
 			}
@@ -1022,15 +1082,24 @@ int main(int argc, char* argv[]) {
 		sdlWindow = SDL_CreateWindow("Block Attack - Rise of the Blocks " VERSION_NUMBER,
 		                             SDL_WINDOWPOS_UNDEFINED,
 		                             SDL_WINDOWPOS_UNDEFINED,
-		                             globalData.xsize, globalData.ysize,
+		                             (screenHeight)*4/3, screenHeight,
 		                             createWindowParams );
 		dieOnNullptr(sdlWindow, "Unable to create window");
-		SDL_Renderer* renderer = SDL_CreateRenderer(sdlWindow, -1, 0);
+		int rendererFlags = 0;
+		if (config.softwareRenderer) {
+			rendererFlags |= SDL_RENDERER_SOFTWARE;
+		}
+		SDL_Renderer* renderer = SDL_CreateRenderer(sdlWindow, -1, rendererFlags);
 		dieOnNullptr(renderer, "Unable to create render");
 		if (config.autoScale) {
 			SDL_RenderSetLogicalSize(renderer, 1024, 768);
 			logicalRenderer = true;
 		}
+		if (globalData.verboseLevel) {
+			SDL_RendererInfo info;
+			SDL_GetRendererInfo(renderer, &info);
+			cout << "Renderer: " << info.name << "\n";
+		}
 		globalData.screen = renderer;
 		ResetFullscreen();
 		SetSDLIcon(sdlWindow);
@@ -1039,8 +1108,8 @@ int main(int argc, char* argv[]) {
 			cout << "Images loaded" << "\n";
 		}
 
-		BlockGameSdl theGame = BlockGameSdl(50, 100);            //creates game objects
-		BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500, 100);
+		BlockGameSdl theGame = BlockGameSdl(50, 100, &globalData.spriteHolder->GetDataHolder());            //creates game objects
+		BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500, 100, &globalData.spriteHolder->GetDataHolder());
 		player1 = &theGame;
 		player2 = &theGame2;
 
@@ -1081,7 +1150,7 @@ int main(int argc, char* argv[]) {
 
 
 		//Saves options
-		if (!editorMode) {
+		if (true) {
 			configSettings->setInt("fullscreen",(int)globalData.bFullscreen);
 			configSettings->setInt("musicenabled",(int)globalData.MusicEnabled);
 			configSettings->setInt("soundenabled",(int)globalData.SoundEnabled);
@@ -1102,10 +1171,11 @@ int main(int argc, char* argv[]) {
 
 			configSettings->setString("player1name", globalData.player1name);
 			configSettings->setString("player2name", globalData.player2name);
-			if (!config.autoScale) {
-				//autoScale is always equal the logical size, so it makes no sense to save it
-				configSettings->setInt("xsize", globalData.xsize);
-				configSettings->setInt("ysize", globalData.ysize);
+			{
+				//Store physical height of window
+				int height = 0;
+				SDL_GetWindowSize(sdlWindow, nullptr, &height);
+				configSettings->setInt("screenHeight", height);
 			}
 			configSettings->save();
 		}
@@ -1139,15 +1209,15 @@ int runGame(Gametype gametype, int level) {
 	globalData.theTopScoresTimeTrial = Highscore("timetrial");
 	drawBalls = true;
 	puzzleLoaded = false;
-	bool bNearDeath = false;                        //Play music faster or louder while tru
+	bool bNearDeath = false;  //Play music faster or louder while tru
 
 	theBallManager = BallManager();
 	theExplosionManager = ExplosionManager();
-	BlockGameSdl theGame = BlockGameSdl(50,100);            //creates game objects
-	BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500,100);
+	BlockGameSdl theGame = BlockGameSdl(50, 100, &globalData.spriteHolder->GetDataHolder());  //creates game objects
+	BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500, 100, &globalData.spriteHolder->GetDataHolder());
 	player1 = &theGame;
 	player2 = &theGame2;
-	theGame.DoPaintJob();           //Makes sure what there is something to paint
+	theGame.DoPaintJob();  //Makes sure what there is something to paint
 	theGame2.DoPaintJob();
 	BlockGameAction a;
 	a.action = BlockGameAction::Action::SET_GAME_OVER;
@@ -1272,12 +1342,19 @@ int runGame(Gametype gametype, int level) {
 					done = 1;
 				}
 
+				if (event.type == SDL_CONTROLLERBUTTONDOWN) {
+					if ( event.cbutton.button == SDL_CONTROLLER_BUTTON_BACK ) {
+						done=1;
+						DrawBackground(globalData.screen);
+					}
+				}
+
 				if ( event.type == SDL_KEYDOWN ) {
 					if ( event.key.keysym.sym == SDLK_ESCAPE || ( event.key.keysym.sym == SDLK_RETURN && theGame.isGameOver() ) ) {
 						done=1;
 						DrawBackground(globalData.screen);
 					}
-					if ((!editorMode)&&(!editorModeTest)&&(!theGame.GetAIenabled())) {
+					if (!theGame.GetAIenabled()) {
 						//player1:
 						if ( event.key.keysym.sym == keySettings[player1keys].up ) {
 							a.action = BlockGameAction::Action::MOVE;
@@ -1308,7 +1385,7 @@ int runGame(Gametype gametype, int level) {
 							theGame.DoAction(a);
 						}
 					}
-					if (!editorMode && !theGame2.GetAIenabled()) {
+					if (!theGame2.GetAIenabled()) {
 						//player2:
 						if ( event.key.keysym.sym == keySettings[player2keys].up ) {
 							a.action = BlockGameAction::Action::MOVE;
@@ -1340,7 +1417,7 @@ int runGame(Gametype gametype, int level) {
 						}
 					}
 					//common:
-					if ((!singlePuzzle)&&(!editorMode)) {
+					if (!singlePuzzle) {
 						if ( event.key.keysym.sym == SDLK_F2 ) {
 							/*#if NETWORK
 							if ((!showOptions)&&(!networkActive)){
@@ -1526,7 +1603,7 @@ int runGame(Gametype gametype, int level) {
 				bMouseUp2=true;
 			}
 
-			if (!editorMode ) {
+			if (true ) {
 				//read mouse events
 				if (SDL_GetMouseState(nullptr,nullptr)&SDL_BUTTON(1) && bMouseUp) {
 					//This is the mouse events
@@ -1566,20 +1643,20 @@ int runGame(Gametype gametype, int level) {
 		//Sees if music is stopped and if music is enabled
 		if ((!globalData.NoSound)&&(!Mix_PlayingMusic())&&(globalData.MusicEnabled)&&(!bNearDeath)) {
 			// then starts playing it.
-			Mix_PlayMusic(bgMusic, -1); //music loop
+			Mix_PlayMusic(bgMusic.get(), -1); //music loop
 			Mix_VolumeMusic((MIX_MAX_VOLUME*3)/10);
 		}
 
 		if (bNearDeath!=bNearDeathPrev) {
 			if (bNearDeath) {
 				if (!globalData.NoSound &&(globalData.MusicEnabled)) {
-					Mix_PlayMusic(highbeatMusic, 1);
+					Mix_PlayMusic(highbeatMusic.get(), 1);
 					Mix_VolumeMusic((MIX_MAX_VOLUME*5)/10);
 				}
 			}
 			else {
 				if (!globalData.NoSound &&(globalData.MusicEnabled)) {
-					Mix_PlayMusic(bgMusic, -1);
+					Mix_PlayMusic(bgMusic.get(), -1);
 					Mix_VolumeMusic((MIX_MAX_VOLUME*3)/10);
 				}
 			}
