@@ -25,6 +25,10 @@ http://blockattack.net
 #include <stdlib.h>
 #include "MenuSystem.h"
 #include "common.h"
+#include "HelpHowtoState.hpp"
+#include "HelpGamepadState.hpp"
+#include "HelpAboutState.hpp"
+#include "ShowFileState.hpp"
 
 using std::string;
 using std::cerr;
@@ -52,8 +56,44 @@ void OpenScoresDisplay();
 extern control keySettings[3];
 
 //Function to return the name of a key, to be displayed...
-static string getKeyName(SDL_Keycode key) {
+string getKeyName(SDL_Keycode key) {
 	string keyname(SDL_GetKeyName(key));
+	if (key == SDLK_UP) {
+		keyname = _("Up arrow");
+	}
+	if (key == SDLK_DOWN) {
+		keyname = _("Down arrow");
+	}
+	if (key == SDLK_LEFT) {
+		keyname = _("Left arrow");
+	}
+	if (key == SDLK_RIGHT) {
+		keyname = _("Right arrow");
+	}
+	if (key == SDLK_RCTRL) {
+		keyname = _("Right Ctrl");
+	}
+	if (key == SDLK_LCTRL) {
+		keyname = _("Left Ctrl");
+	}
+	if (key == SDLK_RSHIFT) {
+		keyname = _("Right shift");
+	}
+	if (key == SDLK_LSHIFT) {
+		keyname = _("Left shift");
+	}
+	if (key == SDLK_RALT) {
+		keyname = _("Right alt");
+	}
+	if (key == SDLK_LALT) {
+		keyname = _("Left alt");
+	}
+	if (key == SDLK_RETURN) {
+		keyname = _("Return");
+	}
+	if (key == SDLK_SPACE) {
+		keyname = _("Space");
+	}
 	if (globalData.verboseLevel) {
 		cout << key << " translated to " << keyname << "\n";
 	}
@@ -96,7 +136,6 @@ void Button_changekey::doAction() {
 
 void InitMenues() {
 	standardButton.setSurfaces();
-	standardButton.thefont = &globalData.nf_button_font;
 }
 
 static void runSinglePlayerEndless() {
@@ -267,10 +306,51 @@ static void MultiplayerMenu() {
 	RunGameState(mm);
 }
 
-void MainMenu() {
-	InitMenues();
-	Menu m(globalData.screen,_("Block Attack - Rise of the blocks"),false);
-	Button bHi,bTimetrial1, bStageClear, bPuzzle, bVs1, bMulti, bConfigure,bHighscore;
+static void runHowto() {
+	HelpHowtoState howto;
+	RunGameState(howto);
+}
+
+static void runHelpGamepad() {
+	HelpGamepadState helpGamepad;
+	RunGameState(helpGamepad);
+}
+
+static void runHelpAbout() {
+	HelpAboutState helpAbout;
+	RunGameState(helpAbout);
+}
+
+static void runCredits() {
+	ShowFileState creditsFile;
+	creditsFile.SetData("misc/AUTHORS", _("Credits"));
+	RunGameState(creditsFile);
+}
+
+static void HelpMenu() {
+	Menu m(globalData.screen, _("Help"), true);
+	Button bHowto;
+	bHowto.setLabel(_("How to"));
+	bHowto.setAction(runHowto);
+	m.addButton(&bHowto);
+	Button bGamepad;
+	bGamepad.setLabel(_("Gamepad"));
+	bGamepad.setAction(runHelpGamepad);
+	m.addButton(&bGamepad);
+	Button bCredits;
+	bCredits.setLabel(_("Credits"));
+	bCredits.setAction(runCredits);
+	m.addButton(&bCredits);
+	Button bAbout;
+	bAbout.setLabel(_("About"));
+	bAbout.setAction(runHelpAbout);
+	m.addButton(&bAbout);
+	RunGameState(m);
+}
+
+static void SinglePlayerMenu() {
+	Menu m(globalData.screen, _("Single player"), true);
+	Button bHi,bTimetrial1, bStageClear, bPuzzle, bVs1;
 	bHi.setLabel(_("Single player - endless") );
 	bHi.setAction(runSinglePlayerEndless);
 	bTimetrial1.setLabel(_("Single player - time trial") );
@@ -281,19 +361,32 @@ void MainMenu() {
 	bPuzzle.setAction(runSinglePlayerPuzzle);
 	bVs1.setLabel(_("Single player - vs") );
 	bVs1.setAction(SinglePlayerVsMenu);
+	m.addButton(&bHi);
+	m.addButton(&bTimetrial1);
+	m.addButton(&bStageClear);
+	m.addButton(&bPuzzle);
+	m.addButton(&bVs1);
+	RunGameState(m);
+}
+
+void MainMenu() {
+	InitMenues();
+	Menu m(globalData.screen,_("Block Attack - Rise of the blocks"),false);
+	Button bHi, bMulti, bConfigure, bHighscore, bHelp;
+	bHi.setLabel(_("Single player") );
+	bHi.setAction(SinglePlayerMenu);
 	bMulti.setLabel(_("Multi player") );
 	bMulti.setAction(MultiplayerMenu);
 	bConfigure.setLabel(_("Configure") );
 	bConfigure.setAction(ConfigureMenu);
 	bHighscore.setLabel(_("Highscores") );
 	bHighscore.setAction(buttonActionHighscores);
+	bHelp.setLabel(_("Help"));
+	bHelp.setAction(HelpMenu);
 	m.addButton(&bHi);
-	m.addButton(&bTimetrial1);
-	m.addButton(&bStageClear);
-	m.addButton(&bPuzzle);
-	m.addButton(&bVs1);
 	m.addButton(&bMulti);
 	m.addButton(&bConfigure);
 	m.addButton(&bHighscore);
+	m.addButton(&bHelp);
 	RunGameState(m);
 }
