@@ -42,6 +42,7 @@ struct SagoDataHolder::SagoDataHolderData {
 	std::vector<SDL_RWops*> rwOpsToFree;
 	std::vector<std::unique_ptr<char[]>> dataToFree;
 	bool verbose = false;
+	Uint64 version = 0;
 	SDL_Renderer* renderer = nullptr;
 };
 
@@ -49,33 +50,55 @@ static void printFileWeLoad(const std::string& value) {
 	std::cout << "Loading " << value << "\n";
 }
 
+SagoDataHolder::SagoDataHolder() {
+	data = new SagoDataHolderData();
+}
+
 SagoDataHolder::SagoDataHolder(SDL_Renderer* renderer) {
 	data = new SagoDataHolderData();
 	data->renderer = renderer;
 }
 
-SagoDataHolder::~SagoDataHolder() {
+void SagoDataHolder::invalidateAll(SDL_Renderer* renderer) {
+	invalidateAll();
+	data->renderer = renderer;
+}
+
+void SagoDataHolder::invalidateAll() {
+	data->version++;
 	for (auto& item : data->textures) {
 		SDL_DestroyTexture(item.second);
 	}
+	data->textures.clear();
 	for (auto& item : data->music) {
 		Mix_FreeMusic(item.second);
 	}
+	data->music.clear();
 	for (auto& item : data->sounds) {
 		Mix_FreeChunk(item.second);
 	}
+	data->sounds.clear();
 	for (auto& item : data->fonts) {
 		for (auto& item2 : item.second) {
 			TTF_CloseFont(item2.second);
 		}
 	}
+	data->fonts.clear();
 	for (auto& item : data->rwOpsToFree) {
 		SDL_FreeRW(item);
 	}
+	data->rwOpsToFree.clear();
+}
+
+SagoDataHolder::~SagoDataHolder() {
+	invalidateAll();
 	delete data;
 }
 
 SDL_Texture* SagoDataHolder::getTexturePtr(const std::string& textureName) const {
+	if (!data->renderer) {
+		throw std::runtime_error("SagoDataHolder used before setting the renderer");
+	}
 	SDL_Texture* ret = data->textures[textureName];
 	if (ret) {
 		return ret;
@@ -244,4 +267,67 @@ void SagoDataHolder::setVerbose(bool value) {
 	data->verbose = value;
 }
 
+Uint64 SagoDataHolder::getVersion() const {
+	return data->version;
+}
+
+TextureHandler::TextureHandler(const SagoDataHolder* holder, const std::string &textureName) {
+	this->holder = holder;
+	this->version = this->holder->getVersion();
+	this->textureName = textureName;
+	this->data = this->holder->getTexturePtr(this->textureName);
+}
+
+SDL_Texture* TextureHandler::get() {
+	if (version != holder->getVersion()) {
+		//The holder has been invalidated
+		this->data = this->holder->getTexturePtr(textureName);
+	}
+	return data;
+}
+
+
+MusicHandler::MusicHandler(const SagoDataHolder* holder, const std::string& musicName) {
+	this->holder = holder;
+	this->version = this->holder->getVersion();
+	this->musicName = musicName;
+	this->data = this->holder->getMusicPtr(this->musicName);
+}
+
+Mix_Music* MusicHandler::get() {
+	if (version != holder->getVersion()) {
+		//The holder has been invalidated
+		this->data = this->holder->getMusicPtr(musicName);
+	}
+	return data;
+}
+
+SoundHandler::SoundHandler(const SagoDataHolder* holder, const std::string& soundName) {
+	this->holder = holder;
+	this->version = this->holder->getVersion();
+	this->soundName = soundName;
+	this->data = this->holder->getSoundPtr(this->soundName);
+}
+
+Mix_Chunk* SoundHandler::get() {
+	if (version != holder->getVersion()) {
+		//The holder has been invalidated
+		this->data = this->holder->getSoundPtr(soundName);
+	}
+	return data;
+}
+
+
+TextureHandler SagoDataHolder::getTextureHandler(const std::string &textureName) const {
+	return TextureHandler(this, textureName);
+}
+
+MusicHandler SagoDataHolder::getMusicHandler(const std::string &musicName) const {
+	return MusicHandler(this, musicName);
+}
+
+SoundHandler SagoDataHolder::getSoundHandler(const std::string &soundName) const {
+	return SoundHandler(this, soundName);
+}
+
 } //name space sago
