@@ -28,9 +28,9 @@ SOFTWARE.
 namespace sago {
 
 struct SagoSprite::SagoSpriteData {
-	SDL_Texture* tex = nullptr;
-	SDL_Rect imgCord{};
-	SDL_Rect origin{};
+	TextureHandler tex;
+	SDL_Rect imgCord = {};
+	SDL_Rect origin = {};
 	int aniFrames = 0;
 	int aniFrameTime = 0;
 };
@@ -41,7 +41,7 @@ SagoSprite::SagoSprite() {
 
 SagoSprite::SagoSprite(const SagoDataHolder& texHolder, const std::string& texture,const SDL_Rect& initImage,const int animationFrames, const int animationFrameLength) {
 	data = new SagoSpriteData();
-	data->tex = texHolder.getTexturePtr(texture);
+	data->tex = texHolder.getTextureHandler(texture);
 	data->imgCord = initImage;
 	data->aniFrames = animationFrames;
 	data->aniFrameTime = animationFrameLength;
@@ -65,21 +65,21 @@ void SagoSprite::Draw(SDL_Renderer* target, Sint32 frameTime, int x, int y) cons
 }
 
 void SagoSprite::DrawScaled(SDL_Renderer* target, Sint32 frameTime, int x, int y, int w, int h) const {
-	if (!data->tex) {
+	if (!data->tex.get()) {
 		std::cerr << "Texture is null!\n";
 	}
 	SDL_Rect rect = data->imgCord;
 	rect.x+=rect.w*((frameTime/data->aniFrameTime)%data->aniFrames);
 	SDL_Rect pos = rect;
-	pos.x = x;
-	pos.y = y;
+	pos.x = x - this->data->origin.x;
+	pos.y = y - this->data->origin.y;
 	if (w > 0) {
 		pos.w = w;
 	}
 	if (h > 0) {
 		pos.h = h;
 	}
-	SDL_RenderCopy(target, data->tex, &rect, &pos);
+	SDL_RenderCopy(target, data->tex.get(), &rect, &pos);
 }
 
 void SagoSprite::Draw(SDL_Renderer* target, Sint32 frameTime, int x, int y, const SDL_Rect& part) const {
@@ -90,9 +90,15 @@ void SagoSprite::Draw(SDL_Renderer* target, Sint32 frameTime, int x, int y, cons
 	rect.w = part.w;
 	rect.h = part.h;
 	SDL_Rect pos = rect;
-	pos.x = x;
-	pos.y = y;
-	SDL_RenderCopy(target, data->tex, &rect, &pos);
+	pos.x = x - this->data->origin.x;
+	pos.y = y - this->data->origin.y;
+	SDL_RenderCopy(target, data->tex.get(), &rect, &pos);
+}
+
+void SagoSprite::DrawProgressive(SDL_Renderer* target, float progress, int x, int y) const {
+	Sint32 frameNumber = progress*data->aniFrames;
+	Sint32 frameTime = frameNumber*data->aniFrameTime;
+	Draw(target, frameTime, x, y);
 }
 
 void SagoSprite::DrawBounded(SDL_Renderer* target, Sint32 frameTime, int x, int y, const SDL_Rect& bounds) const {
@@ -138,7 +144,7 @@ void SagoSprite::DrawBounded(SDL_Renderer* target, Sint32 frameTime, int x, int
 		rect.h -= absDiff;
 	}
 
-	SDL_RenderCopy(target, data->tex, &rect, &pos);
+	SDL_RenderCopy(target, data->tex.get(), &rect, &pos);
 }
 
 void SagoSprite::SetOrigin(const SDL_Rect& newOrigin) {
