@@ -68,7 +68,7 @@ Stats* Stats::getInstance() {
 void Stats::save() {
 	std::stringstream outFile;
 	map<string,unsigned int>::iterator iter;
-	for (iter = statMap.begin(); iter != statMap.end(); iter++) {
+	for (iter = statMap.begin(); iter != statMap.end(); ++iter) {
 		outFile << iter->first << " " << iter->second << "\n";
 	}
 	sago::WriteFileContent(statsFileName, outFile.str());
